#' @keywords internal
"_PACKAGE"

## gptstudio namespace: start
#' @import cli
#' @import rlang
#' @importFrom assertthat assert_that is.string is.number is.count
#' @importFrom glue glue
## gptstudio namespace: end
gptstudio_env <- new.env()
